==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/categories.php <==
<?php
/*
  categories.php
  2004/12/2
ǽ2005/6/1

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/
?>
<!-- categories //-->
<?php
  if (KN_CFG_CATEGORIES_DISPLAY == 'true') {
    if ( (!isset($display_category_id)) || ($display_category_id == '0') ) {
      $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '0' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
    } else {
      if (is_array($display_category_id)) {
        for($i=0, $n=sizeof($display_category_id); $i<$n; $i++) {
          $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_category_id[$i] . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
          if (tep_db_num_rows($display_categories_query) < 1) {
            // do nothing, go through the loop
          } else {
            break; // we've found the deepest category the customer is in
          }
        }
      } else {
        $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_category_id . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
      }
    }

    $num_categories = tep_db_num_rows($display_categories_query);
    if (0 < $num_categories) {
      echo '<table id="categoriesTable">' . "\n";

      $col = 0;
      $width = (int)(100 / KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW) . '%';

      while ($display_categories = tep_db_fetch_array($display_categories_query)) {
        if ($col == 0) {
          echo '<tr>';
        }
        $cPath_new = tep_get_path($display_categories['categories_id']);
        echo '<td width="' . $width . '" class="categoriesField">';
        switch (KN_CFG_CATEGORIES_DISPLAY_TYPE) {
          case 'type2':
            if (SHOW_COUNTS == 'true') {
              $products_in_display_category = '<span class="pCount">(' . tep_count_products_in_category($display_categories['categories_id']) . ')</span>';
            } else {
              $products_in_display_category = '';
            }
            echo '<a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '"><span class="cName">' . $display_categories['categories_name'] . '</span></a>' . $products_in_display_category;
            break;
          case 'type1':
          default:
            echo '<a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '"><div class="cName">' . $display_categories['categories_name'] . '</div></a>';
            $child_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_categories['categories_id'] . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
            if (tep_db_num_rows($child_categories_query) > 0) {
        	     while ($child_categories = tep_db_fetch_array($child_categories_query)) {
                $cPath_new = tep_get_path($child_categories['categories_id']);
        	       echo '&nbsp;' . '<a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '"><span class="cChildName">' . $child_categories['categories_name'] . '</span></a>';
        	     }
            }
        }
        echo '</td>';
        $col ++;
        if ($col == KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW) {
          echo '</tr>' . "\n";
          $col = 0;
        }
      }
      if ($col>0) {
        for ($i=$col; $i < KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW; $i++) {
          echo '<td width="' . $width . '" class="categoriesField">&nbsp;</td>';
        }
        echo '</tr>' . "\n";
      }
      echo '</table>' . "\n";
    }
  }
?>
<!-- categories_eof //-->

==> koshoten.net-2.2.0.tar.gz: koshoten-net/catalog/includes/modules/categories.php <==
<?php
/*
  $Id: categories.php,v 1.2 2006/07/16 05:09:36 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/
?>
<!-- categories -->
<?php
  if (KN_CFG_CATEGORIES_DISPLAY == 'true') {
    if ( (!isset($display_category_id)) || ($display_category_id == '0') ) {
      $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '0' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
    } else {
      if (is_array($display_category_id)) {
        for($i=0, $n=sizeof($display_category_id); $i<$n; $i++) {
          $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_category_id[$i] . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
          if (tep_db_num_rows($display_categories_query) < 1) {
            // do nothing, go through the loop
          } else {
            break; // we've found the deepest category the customer is in
          }
        }
      } else {
        $display_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_category_id . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
      }
    }

    $num_categories = tep_db_num_rows($display_categories_query);
    if (0 < $num_categories) {
      echo '<table border="0" class="categories">' . "\n";

      $col = 0;
      $width = (int)(100 / KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW) . '%';

      while ($display_categories = tep_db_fetch_array($display_categories_query)) {
        if ($col == 0) {
          echo '<tr>';
        }
        $cPath_new = tep_get_path($display_categories['categories_id']);
        echo '<td width="' . $width . '">' . "\n";
        switch (KN_CFG_CATEGORIES_DISPLAY_TYPE) {
          case 'type2':
            if (SHOW_COUNTS == 'true') {
              $products_in_display_category = '(' . tep_count_products_in_category($display_categories['categories_id']) . ')';
            } else {
              $products_in_display_category = '';
            }
            echo '<p><a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '"><span class="cName">' . $display_categories['categories_name'] . '</span>' . $products_in_display_category . "</a></p>\n";
            break;
          case 'type1':
          default:
            echo '<p><a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '"><span class="cName">' . $display_categories['categories_name'] . "</span></a></p>\n";
            $child_categories_query = tep_db_query("select c.categories_id, cd.categories_name, c.categories_image, c.parent_id from " . TABLE_CATEGORIES . " c, " . TABLE_CATEGORIES_DESCRIPTION . " cd where c.parent_id = '" . $display_categories['categories_id'] . "' and c.categories_id = cd.categories_id and cd.language_id = '" . $languages_id . "' order by sort_order, cd.categories_name");
            if (tep_db_num_rows($child_categories_query) > 0) {
            	echo "<ul>\n";
        	     while ($child_categories = tep_db_fetch_array($child_categories_query)) {
                $cPath_new = tep_get_path($child_categories['categories_id']);
        	       echo '<li><a href="' . tep_href_link(FILENAME_DEFAULT, $cPath_new) . '">' . $child_categories['categories_name'] . "</a>\n";
        	     }
            }
        }
        echo "</td>\n";
        $col ++;
        if ($col == KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW) {
          echo "</tr>\n";
          $col = 0;
        }
      }
      if ($col>0) {
        for ($i=$col; $i < KN_CFG_MAX_DISPLAY_CATEGORIES_PER_ROW; $i++) {
          echo '<td width="' . $width . '">&nbsp;</td>' . "\n";
        }
        echo "</tr>\n";
      }
      echo "</table>\n";
    }
  }
?>
<!-- /categories -->
